.\" Manual page for the FITS FIle Index Generator (fitsidx)
.\"
.\" 08 August 1996, a.c.raugh.  Re-written from PDSIDX model
.\" 22 Aug 2005, ACR: Fixed numerous typos.
.\"
.TH FITSIDX L "08 August 1996"
.SH NAME
fitsidx \- Index table generator for FITS files
.SH SYNOPSIS
.B fitsidx
.RB "[\| " \-a " \|] [\| " \-n " \|] [\| " \-r " \|] "
.RB" [\| " \-o
.I <output file>
.RB " \|] [\| " \-f
.I <keyword list file>
.RB " \|] [\| " \-d
.I <root directory>
.RB " \|] [\| [\|"
.I <keyword>/<width>
.RB "\|] " ... " \|] "
.SH DESCRIPTION
.LP
.B fitsidx
searches FITS headers and
extracts keyword values to generate an index.  
Files ending in ".fits", ".fit", ".fts", and ".hdr" are assumed to be potential
FITS file, but these are always checked for the "SIMPLE = T" first line before
processing is carried out. Non-FITS files are ignored silently.
FITS headers may be attached or detached.
.LP
The user may specify keywords in
addition to or instead of the default keywords; output widths and justification
(left or right) may also be specified.  All columns in the output file are
listed in the order of specification, with default keywords coming first; all 
columns are separated by a single space.
.\"---------------------------------------------------------------------------
.SH OPTIONS
.TP
.B \-a
Checks all files in the directory, regardless of extension, to see if they
begin with a FITS header.  The default behavior is to only check files
with extensions of ".fits", ".fit", ".fts", and ".hdr".
.TP
.B \-n
No default keywords \- do not include the default values in the output index
.TP
.B \-r
Descend recursively through all subdirectories and include all FITS files
found
.TP
.BI \-o " output_file"
Direct the output to the named file.  Output goes to stdout by default.
.TP
.BI \-f " keyword_list_file"
Read a list of keywords and widths from the given file.  These should
be in the same format as the command-line keywords.  Values from this file will
be included after the default keywords and before command-line keywords.
.TP
.BI \-d " root_directory"
The directory in which to root the search.  Default is the current working
directory.
.\"
.\"
.\"
.SH KEYWORD SPECIFIERS
.LP
.B fitsidx
takes an optional list of keywords and widths on the command line.  When
included, they are placed after the default keywords and any others
read from the keyword_list_file.
.LP
Keyword specifiers must be in the format: <keyword>/<width>, where
"keyword" is the FITS keyword to be included and "width" is the number of
columns to allow in the output listing ("width" defaults to 10 if omitted).
A negative value for "width" indicates that the field should be left-justified
in the output listing (right-justification is the default).
Top-level keywords (i.e., those not in XTENSION headers) are 
specified using just the keyword itself.  For keywords in extensions, include 
the extension type as a path, adding a subscript for each additional header
of that type.  For example:
.sp
BINTABLE.BITPIX/5
.sp
indicates that the BITPIX keyword from the first BINTABLE extension header 
should be included in
the output list, with a width of 5 characters.
.sp
IMAGE[2].NAXIS1/3
.sp
indicates that the NAXIS1 value of the second IMAGE extension header should
be included, using the a width of 3 characters.
Objects are numbered
from 1; if an object subscript is not included it is assumed to be 1.
Subscripts count XTENSION headers only; never the primary header.
.LP
There are also several special identifiers used to indicate information which
might be desired in an index listing but which does not have a clear keyword
association.  These are:
.sp
.ta 5 +12
.TP
.B ^PATH
The path from the root directory to the file directory
.TP
.B ^FILE
The full name of the data file, with extension but without
any path name 
.LP
The default keyword specifiers are:
.sp
	^PATH
.br
	^FILE
.br
	BITPIX
.br
	NAXIS
.sp
.\"
.SH FILES
.TP
.B Keyword list file
A list of keyword specifiers, one per line.  These should be in the same
format as those on the command line.  The "#" character is used to indicate
comments \- anything following it on the line is ignored.  Blank lines are
also ignored.
