#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <ctype.h>

int get_args(int, char *[], char *, int *, char [], char []);
    /* ... command line argument parser ... */

/* 
   FITSPAD : This routine reads a file, counts the bytes, and pads it with
             blanks out to a multiple of 2880 bytes.

   Format:

             $ fitspad [ -n ] [ source [ output ] ]

   If no file arguments are given stdin and stdout are used.  If only one
   file argument is given, it is assumed to be the input file.  Wild cards
   are not allowed.  The "-n" switch indicates that the file should be
   padded with nulls ('\0") rather than blank characters.

*/
/* Modification History:

   02 Feb 1993: creation (a.c.raugh)
   11 Jun 1996, acr: changed function prototype and definition line to 
                     adhere to ANSI Standard C
   23 Dec 1996, acr: added silent running mode
*/

#define BUFFERSIZE 2880   /* I/O buffer length         */
#define BLANK      ' '    /* blank character           */

main (argc, argv)
  int argc;
  char *argv[];
{
    extern int errno; /* system error code                    */

    FILE *infile;     /* input file pointer                   */
    FILE *outfile;    /* output file pointer                  */

    int recs;         /* number of records read               */
    int i,j,k;        /* loop/subscript variables             */
    char buffer[BUFFERSIZE]; /* FITS record buffer            */
    size_t bytes_read;/* number of bytes read from input file */
    size_t recs_wrtn; /* number of FITS records written       */
    char pad;         /* character to be used to pad out bocks*/
    int  noisy;       /* 0 will supress end messages          */

    char ifile[100];  /* input file name                      */
    char ofile[100];  /* output file name                     */
    int infarg;       /* argument number of input file name   */
    int outfarg;      /* argument number of output file name  */

/*  Get arguments from command line:
*/
    if ((i = get_args(argc,argv,&pad,&noisy,ifile,ofile)) != 0)
        return i;   /* error reading input */

/*  Open files, set width and initialize record count:
*/
    if (strcmp(ifile,"stdin") == 0)
        infile = stdin;
    else
      { if ((infile = fopen(ifile,"r")) == NULL)
          { fprintf(stderr," fitspad: Unable to open %s for reading (%s)\n",
                            ifile, strerror(errno));
            return 2;
          }
       }

    if (strcmp(ofile,"stdout") == 0)
        outfile = stdout;
    else
      { if ((outfile = fopen(ofile,"w")) == NULL)
          { fprintf(stderr," fitspad: Unable to open %s for writing (%s)\n",
                            ofile, strerror(errno));
            return 3;
          }
      }

    recs  = 0;

/*  Loop through FITS blocks in file:
*/
    while ((bytes_read = fread ((void *)buffer, 1, BUFFERSIZE, infile))
               == BUFFERSIZE)
      { ++recs;
        recs_wrtn = fwrite ((void *)buffer, BUFFERSIZE, 1, outfile);
        if (recs_wrtn != 1)
          { fprintf (stderr," fitspad: error writing to output file (%s)\n",
                             strerror(errno));
            return 4;
          }
      }

/* Make sure there hasn't been an error by checking ferror:
*/
    if (ferror(infile))
      { fprintf(stderr, " fitspad: error reading from input (%s)\n",
                         strerror(errno));
        return 5;
      }

/* If there are still some bytes to be printed, pad the output buffer to 2880
   bytes with the padding character and write the last record:
*/
    if (bytes_read > 0)
      { ++recs;
        for (i=bytes_read; i<2880; ++i)
            buffer[i] = pad;
        recs_wrtn = fwrite((void *)buffer, BUFFERSIZE, 1, outfile);
        if (recs_wrtn != 1)
          { fprintf (stderr, " fitspad: error writing to output file (%s)\n",
                              strerror(errno));
            return 4;
          }
      }
    
/*  Report results to standard error:
*/
    if (noisy)
      { fprintf(stderr,"\n%d FITS records written.\n",recs); }

/*  Close files and exit:
*/
    fclose(infile);
    fclose(outfile);
    return 0;
}

/*============================================================================*/

/*  get_args: reads input command parameters and returns them to the caller */

int get_args(int argc, char *argv[], char *pad, int *noisy, 
             char ifile[], char ofile[])
{
    int  i;             /* loop/subscript variable              */ 
 
    *pad = BLANK;    /* default padding character */
    *noisy = 1;      /* default display option    */


    strcpy(ifile,"stdin");
    strcpy(ofile,"stdout");
    i = 1;

    while (i < argc)
      { if (strcmp(argv[i],"-n") == 0)
          { *pad = '\0'; }

        else if (strcmp(argv[i],"-s") == 0)
          { *noisy = 0;  }

        else if (strcmp(ifile,"stdin") == 0)
          { strcpy(ifile,argv[i]); }

        else
          { strcpy(ofile,argv[i]); }
        ++i;
      }


/*  Normal return:
*/
    return 0;
}
