/*
  General routine to fix poorly formatted FITS ASCII tables in which each block
  has been padded rather than just the end of the file.

  05 July 1994, acr
*/

#include <stdio.h>
#include <string.h>
#include <errno.h>


main(argc,argv)
  int     argc;
  char   *argv[];

{ int    record_length;
  int    i,j,k;
  int    records;
  int    blocksin,recsout;
  FILE  *ifp, *ofp;
  char   buffer[2880];
  int    pad_length;
  int    rec_per_block;
  void  *ptr;

  /* Get command line arguments: */

  if (argc < 2 || argc > 4)
    { fprintf (stderr,"Usage: fixfits bytes [ input_file [output_file] ]\n");
      exit(0);
    }

  if (argc == 4)
    { if ((ofp=fopen(argv[3],"w")) == NULL)
        { fprintf (stderr,"fixfits: Unable to open %s for writing (%s).\n",
                           argv[3],strerror(errno));
          exit(1);
        }
    }
  else
      ofp = stdout;

  if (argc > 2)
    { if ((ifp=fopen(argv[2],"r")) == NULL)
        { fprintf (stderr,"fixfits: Unable to open %s for reading (%s).\n",
                           argv[2],strerror(errno));
          exit(2);
        }
    }
  else
      ifp = stdin;

  record_length = atoi(argv[1]);
  if (record_length < 1  ||  record_length > 2880)
    { fprintf (stderr,"fixfits: Invalid record length (%s)\n",argv[1]);
      exit(3);
    }
  rec_per_block = 2880 / record_length;


  /* read through file blocks, writing one record at a time to the output:
  */

  records = blocksin = recsout = 0;

  fread((void *)buffer,1,2880,ifp);
  while (!feof(ifp))
    { ++blocksin;

      /* transfer records one at a time to the output file: */

      for (i=0; i<rec_per_block; ++i)
        { ++records;
          fwrite((void *)(buffer+(i*record_length)),record_length,1,ofp);
          if (ferror(ofp))
            { fprintf (stderr,
                        "fixfits: Write error at record %d, block %d (%s).\n",
                         records, blocksin, strerror(errno));
              exit(10);
            }
        }

      /* next block: */

      fread((void *)buffer,1,2880,ifp);
    }

  /*  Fill in the remaining bytes in this block as necessary to get a 
      multiple of 2880 bytes in the file.
  */

  pad_length = 2880 - (records * record_length) % 2880;
  if (pad_length > 0)
    { buffer[0]=' ';
      for (i=0; i<pad_length; ++i)
        { fwrite((void *)buffer,1,1,ofp);
          if (ferror(ofp))
            { fprintf (stderr, "fixfits: Write error during padding (%s).\n",
                                records, blocksin, strerror(errno));
              exit(10);
            }
        }
    }

  /* close files */

  if (ifp != stdin)  fclose(ifp);
  if (ofp != stdout) fclose(ifp);

  exit(0);
}


      
