/*
   mkstrm:  Routine to turn an ASCII file, presumably with fixed-length
            records, into a stream file by removing all record-delimiting
            characters: linefeed (\n) and carriage-return (\r).  Note that
            these characters are removed wherever they are found, not just
            at regular intervals or when adjacent.  Neither form of delimiter
            is required.  This is most useful for turning ASCII files into
            FITS files, but note that no padding is done.

   Format:  % mkstrm [ input_file [ output_file ] ]

   09 May 1994, acr: creation
   11 Jun 1996, acr: modified to remove both carriage-return and linefeed
*/

#include <stdio.h>
#include <string.h>
#include <errno.h>

main (argc,argv)
  int   argc;
  char *argv[];

{ FILE    *ifp, *ofp;       /* file pointers */
  int      c;               /* input character */


  /* Get and open files: */

  if (argc > 3)
    { fprintf (stderr,"Usage: mkstrm [ input_file [ output_file ] ]\n");
      exit(0);
    }

  if (argc>1)
    { if ((ifp=fopen(argv[1],"r"))==NULL)
        { fprintf (stderr,"mkstrm: Unable to open %s for reading (%s).\n",
                           argv[1],strerror(errno));
          exit(10);
        }
    }
  else
      ifp = stdin;

  if (argc > 2)
    { if ((ofp=fopen(argv[2],"w"))==NULL)
        { fprintf (stderr,"mkstrm: Unable to open %s for writing (%s).\n",
                           argv[2],strerror(errno));
          exit(11);
        }
    }
  else
      ofp = stdout;

/*--------------------------------------------------------------------------*/

  /* Loop through the input file, removing all '\n' adn '\r': */

  while ((c=fgetc(ifp)) != EOF)
    { if (c!='\n'  &&  c!='\r') fputc(c,ofp); }

  /* Close files and exit: */

  if (ifp != stdin)  fclose(ifp);
  if (ofp != stdout) fclose(ofp);
  exit(0);
}
