.\" Manual page for the 'splitfits' routine
.\"
.\" 22 Dec 1993, a.c.raugh.
.\" 11 Jun 1996, acr: added installation notes; upgraded software
.\" 23 Dec 1996, acr: added silent running switch
.\" 29 Jan 1997, acr: completely rewrote to deal with extension headers
.\"
.TH SPLITFITS L "29 January 1997"
.SH NAME
splitfits \- split a FITS file into separate files for header(s) and data,
optionally inserting record delimiters in the header and data files.
.SH SYNOPSIS
.B splitfits
.RB "{\|" \-d
.IR "unix | mac | pc" "\|]"
.RB "[\|" \-h "\|]"
.RB "[\|" \-r "\|]"
.B FITS_file 
.\"------------------
.SH DESCRIPTION
.LP
.B splitfits
breaks a FITS file up into separate header and data files.  If there are
extension headers present, these will also be separated out with
their corresponding data files.
The user may specify that carriage-control record delimiters should be added
to the header or data records by use of the \-h and \-r options, 
respectively.
Header records are always assumed to be 80 bytes wide; the width of the
data records is determined by checking the NAXIS1 value in the corresponding 
header.
.LP
In cases where there are no primary data between the primary header and the
first extension header, the primary and first extension header are output to
the same header file.
Output files have the same base filename as the input FITS file, with extensions
of ".hNN" for headers and ".dNN"
for data, where NN is the sequential number of the data unit within the
FITS file.
.\"------------------
.SH OPTIONS
.TP
.BR \-d " delimiter_type"
The user may specify one of three types of record delimiters: "unix" for 
Unix-style, linefeed (\\n) only delimiters; "mac" for carriage-return (\\r)
only; or "pc" for carriage-return/linefeed (\\r\\n).  Note that the
record length(s) will be expanded by one or two characters to accommodate the
added delimiter(s).  The same delimiter type will be applied to all 
output records.
The default is to use Unix-style delimiters.
.TP
.BR \-h 
This switch indicates that the output header files should have carriage-control
record delimiters inserted.  Delimiters will always be inserted every 80 bytes
in header records.
.TP
.BR \-r
This switch indicates that the output data files should have carriage-control
record delimiters inserted.  Delimiters will be inserted after every NAXIS1
bytes, where NAXIS1 is the value of that keyword in the corresponding header
(and may change from extension to extension).
.\"------------------
.SH USAGE NOTES
.LP
If NAXIS = 0 in the primary data header (indicating no primary data), then the
first extension header will be appended to the primary header, and the header
file and data for that extension will both be numbered "01".
.LP
.B splitfits
does not add or remove bytes from the file, apart from record delimiters.  So
there may be blank lines at the end of header files, or the last line of a 
delimited data file may be shorter than the preceeding lines.  To reconstruct
the original FITS file, merely remove all added record delimiters and 
concatenate headers and data.
.LP
It does not make sense to add delimiters to binary data, but 
.B splitfits
won't stop you from doing it, either.
.\"------------------
.SH INSTALLATION NOTES
.LP
.B splitfits
is contained in a single ANSI Standard C file and should compile without
further modification.  To change the default record delimiter, set the desired
flag value in the \#define statement at the top of the source file.
